@@ -15,10 +15,15 @@
 # Taken from Docker Compose:
 # https://github.com/docker/compose/blob/master/compose/config/interpolation.py
 """Interpolation Module."""
+from __future__ import annotations
 
 import string
 
-from collections.abc import MutableMapping
+from typing import TYPE_CHECKING
+
+
+if TYPE_CHECKING:
+    from collections.abc import Mapping, MutableMapping
 
 
 class InvalidInterpolation(Exception):  # noqa: N818
@@ -77,16 +82,21 @@ class Interpolator:
 
     def __init__(
         self,
-        templater: type["TemplateWithDefaults"],
+        templater: type[TemplateWithDefaults],
         mapping: MutableMapping,  # type: ignore[type-arg]
     ) -> None:
-        """Construct Interpolator."""
+        """Construct Interpolator.
+
+        Args:
+            templater: A templater class.
+            mapping: A mapping object.
+        """
         self.templater = templater
         self.mapping = mapping
 
     def interpolate(self, string: str, keep_string=None) -> str:  # type: ignore[no-untyped-def]  # pylint: disable=redefined-outer-name  # noqa: ANN001, D102
         try:
-            return self.templater(string).substitute(self.mapping, keep_string)  # type: ignore[no-any-return, no-untyped-call]
+            return self.templater(string).substitute(self.mapping, keep_string)
         except ValueError as e:
             raise InvalidInterpolation(string, e) from e
 
@@ -97,7 +107,7 @@ class TemplateWithDefaults(string.Template):
     idpattern = r"[_a-z][_a-z0-9]*(?::?-[^}]+)?"
 
     # pylint: disable=too-many-return-statements  # pylint: disable=useless-suppression
-    def substitute(self, mapping, keep_string):  # type: ignore[no-untyped-def]  # pylint: disable=arguments-differ  # noqa: ANN001, ANN201, D102
+    def substitute(self, mapping: Mapping[str, object], keep_string: str | None) -> str:  # type: ignore[override]  # pylint: disable=arguments-differ  # noqa: D102
         # Helper function for .sub()
         def convert(mo):  # type: ignore[no-untyped-def]  # noqa: ANN001, ANN202, PLR0911
             # Check the most common path first.
