@@ -18,6 +18,7 @@
 #  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 #  DEALINGS IN THE SOFTWARE.
 """Schema v3 Validation Module."""
+from __future__ import annotations
 
 import json
 import logging
@@ -71,7 +72,10 @@ def validate(c):  # type: ignore[no-untyped-def]  # noqa: ANN001, ANN201
             ),
         ):
             wrong_driver_name = str(exc.message.split()[0])
-            driver_name_err_msg = exc.schema["messages"]["anyOf"]
+            if isinstance(exc.schema, dict):
+                driver_name_err_msg = exc.schema["messages"]["anyOf"]
+            else:
+                driver_name_err_msg = "is not a valid driver name"
             result.append(f"{wrong_driver_name} {driver_name_err_msg}")
         else:
             result.append(exc.message)
