@@ -19,7 +19,6 @@
 #  DEALINGS IN THE SOFTWARE.
 """Ansible Provisioner Module."""
 
-# pylint: disable=too-many-lines
 from __future__ import annotations
 
 import collections
@@ -27,6 +26,7 @@ import copy
 import logging
 import os
 import shutil
+
 from typing import Any
 
 from ansible_compat.ports import cached_property
@@ -35,13 +35,12 @@ from molecule import util
 from molecule.api import drivers
 from molecule.provisioner import ansible_playbook, ansible_playbooks, base
 
+
 LOG = logging.getLogger(__name__)
 
 
 class Ansible(base.Base):
-    """
-    `Ansible` is the default provisioner.  No other provisioner will be \
-    supported.
+    """`Ansible` is the default provisioner.  No other provisioner will be supported.
 
     Molecule's provisioner manages the instances lifecycle.  However, the user
     must provide the create, destroy, and converge playbooks.  Molecule's
@@ -414,11 +413,11 @@ class Ansible(base.Base):
     ```
     """
 
-    def __init__(self, config) -> None:
+    def __init__(self, config) -> None:  # type: ignore[no-untyped-def]  # pylint: disable=useless-parent-delegation  # noqa: ANN001
         """Initialize a new ansible class and returns None.
 
-        :param config: An instance of a Molecule config.
-        :return: None
+        Args:
+            config: An instance of a Molecule config.
         """
         super().__init__(config)
 
@@ -442,20 +441,20 @@ class Ansible(base.Base):
         }
 
     @property
-    def default_options(self):
+    def default_options(self):  # type: ignore[no-untyped-def]  # noqa: ANN201, D102
         d = {"skip-tags": "molecule-notest,notest"}
 
         if self._config.action == "idempotence":
             d["skip-tags"] += ",molecule-idempotence-notest"
 
         if self._config.debug:
-            d["vvv"] = True
-            d["diff"] = True
+            d["vvv"] = True  # type: ignore[assignment]
+            d["diff"] = True  # type: ignore[assignment]
 
         return d
 
     @property
-    def default_env(self):
+    def default_env(self):  # type: ignore[no-untyped-def]  # noqa: ANN201, D102
         # Finds if the current project is part of an ansible_collections hierarchy
         collection_indicator = "ansible_collections"
         # isolating test environment by injects ephemeral scenario directory on
@@ -463,7 +462,10 @@ class Ansible(base.Base):
         # from installing dependencies to user list of collections.
         collections_path_list = [
             util.abs_path(
-                os.path.join(self._config.scenario.ephemeral_directory, "collections"),
+                os.path.join(  # noqa: PTH118
+                    self._config.scenario.ephemeral_directory,
+                    "collections",
+                ),
             ),
         ]
         if collection_indicator in self._config.project_directory:
@@ -475,7 +477,10 @@ class Ansible(base.Base):
         collections_path_list.extend(
             [
                 util.abs_path(
-                    os.path.join(os.path.expanduser("~"), ".ansible/collections"),
+                    os.path.join(  # noqa: PTH118
+                        os.path.expanduser("~"),  # noqa: PTH111
+                        ".ansible/collections",
+                    ),
                 ),
                 "/usr/share/ansible/collections",
                 "/etc/ansible/collections",
@@ -494,10 +499,14 @@ class Ansible(base.Base):
 
         roles_path_list = [
             util.abs_path(
-                os.path.join(self._config.scenario.ephemeral_directory, "roles"),
+                os.path.join(self._config.scenario.ephemeral_directory, "roles"),  # noqa: PTH118
+            ),
+            util.abs_path(
+                os.path.join(self._config.project_directory, os.path.pardir),  # noqa: PTH118
+            ),
+            util.abs_path(
+                os.path.join(os.path.expanduser("~"), ".ansible", "roles"),  # noqa: PTH111, PTH118
             ),
-            util.abs_path(os.path.join(self._config.project_directory, os.path.pardir)),
-            util.abs_path(os.path.join(os.path.expanduser("~"), ".ansible", "roles")),
             "/usr/share/ansible/roles",
             "/etc/ansible/roles",
         ]
@@ -511,8 +520,8 @@ class Ansible(base.Base):
             os.environ,
             {
                 "ANSIBLE_CONFIG": self._config.provisioner.config_file,
-                "ANSIBLE_ROLES_PATH": ":".join(roles_path_list),
-                self._config.ansible_collections_path: ":".join(collections_path_list),
+                "ANSIBLE_ROLES_PATH": ":".join(roles_path_list),  # type: ignore[arg-type]
+                self._config.ansible_collections_path: ":".join(collections_path_list),  # type: ignore[arg-type]
                 "ANSIBLE_LIBRARY": ":".join(self._get_modules_directories()),
                 "ANSIBLE_FILTER_PLUGINS": ":".join(
                     self._get_filter_plugins_directories(),
@@ -521,25 +530,25 @@ class Ansible(base.Base):
         )
         env = util.merge_dicts(env, self._config.env)
 
-        return env
+        return env  # noqa: RET504
 
     @property
-    def name(self):
+    def name(self):  # type: ignore[no-untyped-def]  # noqa: ANN201, D102
         return self._config.config["provisioner"]["name"]
 
     @property
-    def ansible_args(self):
+    def ansible_args(self):  # type: ignore[no-untyped-def]  # noqa: ANN201, D102
         return self._config.config["provisioner"]["ansible_args"]
 
     @property
-    def config_options(self):
+    def config_options(self):  # type: ignore[no-untyped-def]  # noqa: ANN201, D102
         return util.merge_dicts(
             self.default_config_options,
             self._config.config["provisioner"]["config_options"],
         )
 
     @property
-    def options(self):
+    def options(self):  # type: ignore[no-untyped-def]  # noqa: ANN201, D102
         if self._config.action in ["create", "destroy"]:
             return self.default_options
 
@@ -547,12 +556,12 @@ class Ansible(base.Base):
         # NOTE(retr0h): Remove verbose options added by the user while in
         # debug.
         if self._config.debug:
-            o = util.filter_verbose_permutation(o)
+            o = util.filter_verbose_permutation(o)  # type: ignore[no-untyped-call]
 
         return util.merge_dicts(self.default_options, o)
 
     @property
-    def env(self):
+    def env(self):  # type: ignore[no-untyped-def]  # noqa: ANN201, D102
         default_env = self.default_env
         env = self._config.config["provisioner"]["env"].copy()
         # ensure that all keys and values are strings
@@ -562,13 +571,13 @@ class Ansible(base.Base):
         filter_plugins_path = default_env["ANSIBLE_FILTER_PLUGINS"]
 
         try:
-            path = self._absolute_path_for(env, "ANSIBLE_LIBRARY")
+            path = self._absolute_path_for(env, "ANSIBLE_LIBRARY")  # type: ignore[no-untyped-call]
             library_path = f"{library_path}:{path}"
         except KeyError:
             pass
 
         try:
-            path = self._absolute_path_for(env, "ANSIBLE_FILTER_PLUGINS")
+            path = self._absolute_path_for(env, "ANSIBLE_FILTER_PLUGINS")  # type: ignore[no-untyped-call]
             filter_plugins_path = f"{filter_plugins_path}:{path}"
         except KeyError:
             pass
@@ -579,23 +588,23 @@ class Ansible(base.Base):
         return util.merge_dicts(default_env, env)
 
     @property
-    def hosts(self):
+    def hosts(self):  # type: ignore[no-untyped-def]  # noqa: ANN201, D102
         return self._config.config["provisioner"]["inventory"]["hosts"]
 
     @property
-    def host_vars(self):
+    def host_vars(self):  # type: ignore[no-untyped-def]  # noqa: ANN201, D102
         return self._config.config["provisioner"]["inventory"]["host_vars"]
 
     @property
-    def group_vars(self):
+    def group_vars(self):  # type: ignore[no-untyped-def]  # noqa: ANN201, D102
         return self._config.config["provisioner"]["inventory"]["group_vars"]
 
     @property
-    def links(self):
+    def links(self):  # type: ignore[no-untyped-def]  # noqa: ANN201, D102
         return self._config.config["provisioner"]["inventory"]["links"]
 
     @property
-    def inventory(self):
+    def inventory(self):  # type: ignore[no-untyped-def]  # noqa: ANN201
         """Create an inventory structure and returns a dict.
 
         ``` yaml
@@ -618,15 +627,15 @@ class Ansible(base.Base):
                   ansible_connection: docker
         ```
         """
-        dd = self._vivify()
+        dd = self._vivify()  # type: ignore[no-untyped-call]
         for platform in self._config.platforms.instances:
             for group in platform.get("groups", ["ungrouped"]):
                 instance_name = platform["name"]
-                connection_options = self.connection_options(instance_name)
+                connection_options = self.connection_options(instance_name)  # type: ignore[no-untyped-call]
                 molecule_vars = {
                     "molecule_file": "{{ lookup('env', 'MOLECULE_FILE') }}",
-                    "molecule_ephemeral_directory": "{{ lookup('env', 'MOLECULE_EPHEMERAL_DIRECTORY') }}",
-                    "molecule_scenario_directory": "{{ lookup('env', 'MOLECULE_SCENARIO_DIRECTORY') }}",
+                    "molecule_ephemeral_directory": "{{ lookup('env', 'MOLECULE_EPHEMERAL_DIRECTORY') }}",  # noqa: E501
+                    "molecule_scenario_directory": "{{ lookup('env', 'MOLECULE_SCENARIO_DIRECTORY') }}",  # noqa: E501
                     "molecule_yml": "{{ lookup('file', molecule_file) | from_yaml }}",
                     "molecule_instance_config": "{{ lookup('env', 'MOLECULE_INSTANCE_CONFIG') }}",
                     "molecule_no_log": "{{ lookup('env', 'MOLECULE_NO_LOG') or not "
@@ -643,32 +652,33 @@ class Ansible(base.Base):
                 dd["ungrouped"]["vars"] = {}
                 # Children
                 for child_group in platform.get("children", []):
-                    dd[group]["children"][child_group]["hosts"][
-                        instance_name
-                    ] = connection_options
+                    dd[group]["children"][child_group]["hosts"][instance_name] = connection_options
 
-        return self._default_to_regular(dd)
+        return self._default_to_regular(dd)  # type: ignore[no-untyped-call]
 
     @property
-    def inventory_directory(self):
+    def inventory_directory(self):  # type: ignore[no-untyped-def]  # noqa: ANN201, D102
         return self._config.scenario.inventory_directory
 
     @property
-    def inventory_file(self):
-        return os.path.join(self.inventory_directory, "ansible_inventory.yml")
+    def inventory_file(self):  # type: ignore[no-untyped-def]  # noqa: ANN201, D102
+        return os.path.join(self.inventory_directory, "ansible_inventory.yml")  # noqa: PTH118
 
     @property
-    def config_file(self):
-        return os.path.join(self._config.scenario.ephemeral_directory, "ansible.cfg")
+    def config_file(self):  # type: ignore[no-untyped-def]  # noqa: ANN201, D102
+        return os.path.join(  # noqa: PTH118
+            self._config.scenario.ephemeral_directory,
+            "ansible.cfg",
+        )
 
     @cached_property
-    def playbooks(self):
+    def playbooks(self):  # type: ignore[no-untyped-def]  # noqa: ANN201, D102
         return ansible_playbooks.AnsiblePlaybooks(self._config)
 
     @property
-    def directory(self):
-        return os.path.join(
-            os.path.dirname(__file__),
+    def directory(self):  # type: ignore[no-untyped-def]  # noqa: ANN201, D102
+        return os.path.join(  # noqa: PTH118
+            os.path.dirname(__file__),  # noqa: PTH120
             os.path.pardir,
             os.path.pardir,
             "molecule",
@@ -676,16 +686,12 @@ class Ansible(base.Base):
             "ansible",
         )
 
-    def cleanup(self):
-        """Execute `ansible-playbook` against the cleanup playbook and returns \
-        None.
-
-        :return: None
-        """
-        pb = self._get_ansible_playbook(self.playbooks.cleanup)
+    def cleanup(self):  # type: ignore[no-untyped-def]  # noqa: ANN201
+        """Execute `ansible-playbook` against the cleanup playbook and returns None."""
+        pb = self._get_ansible_playbook(self.playbooks.cleanup)  # type: ignore[no-untyped-call]
         pb.execute()
 
-    def connection_options(self, instance_name):
+    def connection_options(self, instance_name):  # type: ignore[no-untyped-def]  # noqa: ANN001, ANN201, D102
         d = self._config.driver.ansible_connection_options(instance_name)
 
         return util.merge_dicts(
@@ -693,92 +699,63 @@ class Ansible(base.Base):
             self._config.config["provisioner"]["connection_options"],
         )
 
-    def check(self):
-        """Execute ``ansible-playbook`` against the converge playbook with the \
-        ``--check`` flag and returns None.
-
-        :return: None
-        """
-        pb = self._get_ansible_playbook(self.playbooks.converge)
-        pb.add_cli_arg("check", True)
+    def check(self):  # type: ignore[no-untyped-def]  # noqa: ANN201
+        """Execute ``ansible-playbook`` against the converge playbook with the ``--check`` flag."""
+        pb = self._get_ansible_playbook(self.playbooks.converge)  # type: ignore[no-untyped-call]
+        pb.add_cli_arg("check", True)  # noqa: FBT003
         pb.execute()
 
-    def converge(self, playbook=None, **kwargs):
-        """Execute ``ansible-playbook`` against the converge playbook unless \
-        specified otherwise and returns a string.
+    def converge(self, playbook=None, **kwargs):  # type: ignore[no-untyped-def]  # noqa: ANN001, ANN003, ANN201
+        """Execute ``ansible-playbook`` against the converge playbook. unless specified otherwise.
 
-        :param playbook: An optional string containing an absolute path to a
-         playbook.
-        :param kwargs: An optional keyword arguments.
-        :return: str
+        Args:
+            playbook: An optional string containing an absolute path to a playbook.
+            kwargs: An optional keyword arguments.
+
+        Returns:
+            str: The output from the ``ansible-playbook`` command.
         """
-        pb = self._get_ansible_playbook(playbook or self.playbooks.converge, **kwargs)
+        pb = self._get_ansible_playbook(playbook or self.playbooks.converge, **kwargs)  # type: ignore[no-untyped-call]
 
         return pb.execute()
 
-    def destroy(self):
-        """Execute ``ansible-playbook`` against the destroy playbook and returns \
-        None.
-
-        :return: None
-        """
-        pb = self._get_ansible_playbook(self.playbooks.destroy)
+    def destroy(self):  # type: ignore[no-untyped-def]  # noqa: ANN201
+        """Execute ``ansible-playbook`` against the destroy playbook and returns None."""
+        pb = self._get_ansible_playbook(self.playbooks.destroy)  # type: ignore[no-untyped-call]
         pb.execute()
 
-    def side_effect(self, action_args=None):
-        """Execute ``ansible-playbook`` against the side_effect playbook and \
-        returns None.
-
-        :return: None
-        """
+    def side_effect(self, action_args=None):  # type: ignore[no-untyped-def]  # noqa: ANN001, ANN201
+        """Execute ``ansible-playbook`` against the side_effect playbook and returns None."""
         if action_args:
             playbooks = [
-                self._get_ansible_playbook(self._config.provisioner.abs_path(playbook))
+                self._get_ansible_playbook(self._config.provisioner.abs_path(playbook))  # type: ignore[no-untyped-call]
                 for playbook in action_args
             ]
         else:
-            playbooks = [self._get_ansible_playbook(self.playbooks.side_effect)]
+            playbooks = [self._get_ansible_playbook(self.playbooks.side_effect)]  # type: ignore[no-untyped-call]
         for pb in playbooks:
             pb.execute()
 
-    def create(self):
-        """Execute ``ansible-playbook`` against the create playbook and returns \
-        None.
-
-        :return: None
-        """
-        pb = self._get_ansible_playbook(self.playbooks.create)
+    def create(self):  # type: ignore[no-untyped-def]  # noqa: ANN201
+        """Execute ``ansible-playbook`` against the create playbook and returns None."""
+        pb = self._get_ansible_playbook(self.playbooks.create)  # type: ignore[no-untyped-call]
         pb.execute()
 
-    def prepare(self):
-        """Execute ``ansible-playbook`` against the prepare playbook and returns \
-        None.
-
-        :return: None
-        """
-        pb = self._get_ansible_playbook(self.playbooks.prepare)
+    def prepare(self):  # type: ignore[no-untyped-def]  # noqa: ANN201
+        """Execute ``ansible-playbook`` against the prepare playbook and returns None."""
+        pb = self._get_ansible_playbook(self.playbooks.prepare)  # type: ignore[no-untyped-call]
         pb.execute()
 
-    def syntax(self):
-        """Execute ``ansible-playbook`` against the converge playbook with the \
-        ``-syntax-check`` flag and returns None.
-
-        :return: None
-        """
-        pb = self._get_ansible_playbook(self.playbooks.converge)
-        pb.add_cli_arg("syntax-check", True)
+    def syntax(self):  # type: ignore[no-untyped-def]  # noqa: ANN201
+        """Execute `ansible-playbook` against the converge playbook with the -syntax-check flag."""
+        pb = self._get_ansible_playbook(self.playbooks.converge)  # type: ignore[no-untyped-call]
+        pb.add_cli_arg("syntax-check", True)  # noqa: FBT003
         pb.execute()
 
-    def verify(self, action_args=None):
-        """Execute ``ansible-playbook`` against the verify playbook and returns \
-        None.
-
-        :return: None
-        """
+    def verify(self, action_args=None):  # type: ignore[no-untyped-def]  # noqa: ANN001, ANN201
+        """Execute ``ansible-playbook`` against the verify playbook and returns None."""
         if action_args:
-            playbooks = [
-                self._config.provisioner.abs_path(playbook) for playbook in action_args
-            ]
+            playbooks = [self._config.provisioner.abs_path(playbook) for playbook in action_args]
         else:
             playbooks = [self.playbooks.verify]
         if not playbooks:
@@ -786,49 +763,40 @@ class Ansible(base.Base):
             return
         for playbook in playbooks:
             # Get ansible playbooks for `verify` instead of `provision`
-            pb = self._get_ansible_playbook(playbook, verify=True)
+            pb = self._get_ansible_playbook(playbook, verify=True)  # type: ignore[no-untyped-call]
             pb.execute()
 
-    def write_config(self):
-        """Write the provisioner's config file to disk and returns None.
-
-        :return: None
-        """
-        template = util.render_template(
-            self._get_config_template(),
+    def write_config(self):  # type: ignore[no-untyped-def]  # noqa: ANN201
+        """Write the provisioner's config file to disk and returns None."""
+        template = util.render_template(  # type: ignore[no-untyped-call]
+            self._get_config_template(),  # type: ignore[no-untyped-call]
             config_options=self.config_options,
         )
         util.write_file(self.config_file, template)
 
-    def manage_inventory(self):
-        """Manage inventory for Ansible and returns None.
-
-        :returns: None
-        """
-        self._write_inventory()
-        self._remove_vars()
+    def manage_inventory(self):  # type: ignore[no-untyped-def]  # noqa: ANN201
+        """Manage inventory for Ansible and returns None."""
+        self._write_inventory()  # type: ignore[no-untyped-call]
+        self._remove_vars()  # type: ignore[no-untyped-call]
         if not self.links:
-            self._add_or_update_vars()
+            self._add_or_update_vars()  # type: ignore[no-untyped-call]
         else:
-            self._link_or_update_vars()
+            self._link_or_update_vars()  # type: ignore[no-untyped-call]
 
-    def abs_path(self, path: str) -> str | None:
-        return util.abs_path(os.path.join(self._config.scenario.directory, path))
+    def abs_path(self, path: str) -> str | None:  # noqa: D102
+        return util.abs_path(os.path.join(self._config.scenario.directory, path))  # noqa: PTH118
 
-    def _add_or_update_vars(self):
-        """Create host and/or group vars and returns None.
-
-        :returns: None
-        """
+    def _add_or_update_vars(self):  # type: ignore[no-untyped-def]  # noqa: ANN202
+        """Create host and/or group vars and returns None."""
         # Create the hosts extra inventory source (only if not empty)
-        hosts_file = os.path.join(self.inventory_directory, "hosts")
+        hosts_file = os.path.join(self.inventory_directory, "hosts")  # noqa: PTH118
         if self.hosts:
             util.write_file(hosts_file, util.safe_dump(self.hosts))
         # Create the host_vars and group_vars directories
         for target in ["host_vars", "group_vars"]:
             if target == "host_vars":
                 vars_target = copy.deepcopy(self.host_vars)
-                for instance_name in self.host_vars.keys():
+                for instance_name in self.host_vars.keys():  # noqa: SIM118
                     instance_key = instance_name
                     vars_target[instance_key] = vars_target.pop(instance_name)
 
@@ -836,70 +804,63 @@ class Ansible(base.Base):
                 vars_target = self.group_vars
 
             if vars_target:
-                target_vars_directory = os.path.join(self.inventory_directory, target)
+                target_vars_directory = os.path.join(  # noqa: PTH118
+                    self.inventory_directory,
+                    target,
+                )
 
-                if not os.path.isdir(util.abs_path(target_vars_directory)):
-                    os.mkdir(util.abs_path(target_vars_directory))
+                if not os.path.isdir(util.abs_path(target_vars_directory)):  # type: ignore[arg-type]  # noqa: PTH112
+                    os.mkdir(util.abs_path(target_vars_directory))  # type: ignore[arg-type]  # noqa: PTH102
 
-                for target in vars_target:
+                for target in vars_target:  # noqa: PLW2901
                     target_var_content = vars_target[target]
-                    path = os.path.join(util.abs_path(target_vars_directory), target)
+                    path = os.path.join(util.abs_path(target_vars_directory), target)  # type: ignore[arg-type]  # noqa: PTH118
                     util.write_file(path, util.safe_dump(target_var_content))
 
-    def _write_inventory(self):
-        """Write the provisioner's inventory file to disk and returns None.
-
-        :return: None
-        """
-        self._verify_inventory()
+    def _write_inventory(self):  # type: ignore[no-untyped-def]  # noqa: ANN202
+        """Write the provisioner's inventory file to disk and returns None."""
+        self._verify_inventory()  # type: ignore[no-untyped-call]
 
         util.write_file(self.inventory_file, util.safe_dump(self.inventory))
 
-    def _remove_vars(self):
-        """Remove hosts/host_vars/group_vars and returns None.
-
-        :returns: None
-        """
+    def _remove_vars(self):  # type: ignore[no-untyped-def]  # noqa: ANN202
+        """Remove hosts/host_vars/group_vars and returns None."""
         for name in ("hosts", "group_vars", "host_vars"):
-            d = os.path.join(self.inventory_directory, name)
-            if os.path.islink(d) or os.path.isfile(d):
-                os.unlink(d)
-            elif os.path.isdir(d):
+            d = os.path.join(self.inventory_directory, name)  # noqa: PTH118
+            if os.path.islink(d) or os.path.isfile(d):  # noqa: PTH113, PTH114
+                os.unlink(d)  # noqa: PTH108
+            elif os.path.isdir(d):  # noqa: PTH112
                 shutil.rmtree(d)
 
-    def _link_or_update_vars(self):
-        """Create or updates the symlink to group_vars and returns None.
-
-        :returns: None
-        """
+    def _link_or_update_vars(self):  # type: ignore[no-untyped-def]  # noqa: ANN202
+        """Create or updates the symlink to group_vars and returns None."""
         for d, source in self.links.items():
-            target = os.path.join(self.inventory_directory, d)
-            source = os.path.join(self._config.scenario.directory, source)
+            target = os.path.join(self.inventory_directory, d)  # noqa: PTH118
+            source = os.path.join(self._config.scenario.directory, source)  # noqa: PTH118, PLW2901
 
-            if not os.path.exists(source):
+            if not os.path.exists(source):  # noqa: PTH110
                 msg = f"The source path '{source}' does not exist."
                 util.sysexit_with_message(msg)
-            if os.path.exists(target):
+            if os.path.exists(target):  # noqa: PTH110
                 if os.path.realpath(target) == os.path.realpath(source):
                     msg = f"Required symlink {target} to {source} exist, skip creation"
                     LOG.debug(msg)
                     continue
                 msg = f"Required symlink {target} exist with another source"
                 LOG.debug(msg)
-                os.remove(target)
+                os.remove(target)  # noqa: PTH107
             msg = f"Inventory {source} linked to {target}"
             LOG.debug(msg)
             os.symlink(source, target)
 
-    def _get_ansible_playbook(self, playbook, verify=False, **kwargs):
+    def _get_ansible_playbook(self, playbook, verify=False, **kwargs):  # type: ignore[no-untyped-def]  # noqa: ANN001, ANN003, ANN202, FBT002
         """Get an instance of AnsiblePlaybook and returns it.
 
-        :param playbook: A string containing an absolute path to a
-         provisioner's playbook.
-        :param verify: An optional bool to toggle the Plabook mode between
-         provision and verify. False: provision; True: verify. Default is False.
-        :param kwargs: An optional keyword arguments.
-        :return: object
+        Args:
+            playbook: A string containing an absolute path to a provisioner's playbook.
+            verify: An optional bool to toggle the Playbook mode between provision and verify.
+                False: provision; True: verify. Default is False.
+            kwargs: An optional keyword arguments.
         """
         return ansible_playbook.AnsiblePlaybook(
             playbook,
@@ -908,19 +869,17 @@ class Ansible(base.Base):
             **kwargs,
         )
 
-    def _verify_inventory(self):
-        """Verify the inventory is valid and returns None.
-
-        :return: None
-        """
+    def _verify_inventory(self):  # type: ignore[no-untyped-def]  # noqa: ANN202
+        """Verify the inventory is valid and returns None."""
         if not self.inventory:
             msg = "Instances missing from the 'platform' section of molecule.yml."
             util.sysexit_with_message(msg)
 
-    def _get_config_template(self):
+    def _get_config_template(self):  # type: ignore[no-untyped-def]  # noqa: ANN202
         """Return a config template string.
 
-        :return: str
+        Returns:
+            str
         """
         return """
 {% for section, section_dict in config_options.items() -%}
@@ -931,24 +890,25 @@ class Ansible(base.Base):
 {% endfor -%}
 """.strip()
 
-    def _vivify(self):
+    def _vivify(self):  # type: ignore[no-untyped-def]  # noqa: ANN202
         """Return an autovivification default dict.
 
-        :return: dict
+        Return:
+            dict
         """
         return collections.defaultdict(self._vivify)
 
-    def _default_to_regular(self, d):
+    def _default_to_regular(self, d):  # type: ignore[no-untyped-def]  # noqa: ANN001, ANN202
         if isinstance(d, collections.defaultdict):
-            d = {k: self._default_to_regular(v) for k, v in d.items()}
+            d = {k: self._default_to_regular(v) for k, v in d.items()}  # type: ignore[no-untyped-call]
 
         return d
 
     def _get_plugin_directory(self) -> str:
-        return os.path.join(self.directory, "plugins")
+        return os.path.join(self.directory, "plugins")  # noqa: PTH118
 
     def _get_modules_directories(self) -> list[str]:
-        """Return list of ansilbe module includes directories.
+        """Return list of ansible module includes directories.
 
         Adds modules directory from molecule and its plugins.
         """
@@ -957,7 +917,7 @@ class Ansible(base.Base):
             paths = list(map(util.abs_path, os.environ["ANSIBLE_LIBRARY"].split(":")))
 
         paths.append(
-            util.abs_path(os.path.join(self._get_plugin_directory(), "modules")),
+            util.abs_path(os.path.join(self._get_plugin_directory(), "modules")),  # noqa: PTH118
         )
 
         for d in drivers():
@@ -967,12 +927,17 @@ class Ansible(base.Base):
         paths.extend(
             [
                 util.abs_path(
-                    os.path.join(self._config.scenario.ephemeral_directory, "library"),
+                    os.path.join(  # noqa: PTH118
+                        self._config.scenario.ephemeral_directory,
+                        "library",
+                    ),
                 ),
-                util.abs_path(os.path.join(self._config.project_directory, "library")),
                 util.abs_path(
-                    os.path.join(
-                        os.path.expanduser("~"),
+                    os.path.join(self._config.project_directory, "library"),  # noqa: PTH118
+                ),
+                util.abs_path(
+                    os.path.join(  # noqa: PTH118
+                        os.path.expanduser("~"),  # noqa: PTH111
                         ".ansible",
                         "plugins",
                         "modules",
@@ -984,11 +949,11 @@ class Ansible(base.Base):
 
         return [path for path in paths if path is not None]
 
-    def _get_filter_plugin_directory(self):
-        return util.abs_path(os.path.join(self._get_plugin_directory(), "filter"))
+    def _get_filter_plugin_directory(self):  # type: ignore[no-untyped-def]  # noqa: ANN202
+        return util.abs_path(os.path.join(self._get_plugin_directory(), "filter"))  # noqa: PTH118
 
     def _get_filter_plugins_directories(self) -> list[str]:
-        """Return list of ansilbe filter plugins includes directories."""
+        """Return list of ansible filter plugins includes directories."""
         paths: list[str | None] = []
         if os.environ.get("ANSIBLE_FILTER_PLUGINS"):
             paths = list(
@@ -997,24 +962,24 @@ class Ansible(base.Base):
 
         paths.extend(
             [
-                self._get_filter_plugin_directory(),
+                self._get_filter_plugin_directory(),  # type: ignore[no-untyped-call]
                 util.abs_path(
-                    os.path.join(
+                    os.path.join(  # noqa: PTH118
                         self._config.scenario.ephemeral_directory,
                         "plugins",
                         "filter",
                     ),
                 ),
                 util.abs_path(
-                    os.path.join(
+                    os.path.join(  # noqa: PTH118
                         self._config.project_directory,
                         "plugins",
                         "filter",
                     ),
                 ),
                 util.abs_path(
-                    os.path.join(
-                        os.path.expanduser("~"),
+                    os.path.join(  # noqa: PTH118
+                        os.path.expanduser("~"),  # noqa: PTH111
                         ".ansible",
                         "plugins",
                         "filter",
@@ -1026,5 +991,5 @@ class Ansible(base.Base):
 
         return [path for path in paths if path is not None]
 
-    def _absolute_path_for(self, env, key):
-        return ":".join([self.abs_path(p) for p in env[key].split(":")])
+    def _absolute_path_for(self, env, key):  # type: ignore[no-untyped-def]  # noqa: ANN001, ANN202
+        return ":".join([self.abs_path(p) for p in env[key].split(":")])  # type: ignore[misc]
