@@ -26,38 +26,37 @@ import fnmatch
 import logging
 import os
 import shutil
+
 from pathlib import Path
 from time import sleep
 
 from molecule import scenarios, util
 from molecule.constants import RC_TIMEOUT
 
+
 LOG = logging.getLogger(__name__)
 
 
 class Scenario:
     """A Molecule scenario."""
 
-    def __init__(self, config) -> None:
+    def __init__(self, config) -> None:  # type: ignore[no-untyped-def]  # noqa: ANN001
         """Initialize a new scenario class and returns None.
 
-        :param config: An instance of a Molecule config.
-        :return: None
+        Args:
+            config: An instance of a Molecule config.
         """
         self._lock = None
         self.config = config
-        self._setup()  # type: ignore
+        self._setup()  # type: ignore[no-untyped-call]
 
-    def _remove_scenario_state_directory(self):
-        """Remove scenario cached disk stored state.
-
-        :return: None
-        """
+    def _remove_scenario_state_directory(self: Scenario) -> None:
+        """Remove scenario cached disk stored state."""
         directory = str(Path(self.ephemeral_directory).parent)
         LOG.info("Removing %s", directory)
         shutil.rmtree(directory)
 
-    def prune(self):
+    def prune(self: Scenario) -> None:
         """Prune the scenario ephemeral directory files and returns None.
 
         "safe files" will not be pruned, including the ansible configuration
@@ -65,7 +64,6 @@ class Scenario:
         files declared as "safe_files" in the ``driver`` configuration
         declared in ``molecule.yml``.
 
-        :return: None
         """
         LOG.info("Pruning extra files from scenario ephemeral directory")
         safe_files = [
@@ -74,11 +72,11 @@ class Scenario:
             self.config.state.state_file,
             *self.config.driver.safe_files,
         ]
-        files = util.os_walk(self.ephemeral_directory, "*")
+        files = util.os_walk(self.ephemeral_directory, "*")  # type: ignore[no-untyped-call]
         for f in files:
             if not any(sf for sf in safe_files if fnmatch.fnmatch(f, sf)):
                 try:
-                    os.remove(f)
+                    os.remove(f)  # noqa: PTH107
                 except OSError as e:
                     if e.errno != errno.ENOENT:
                         raise
@@ -89,25 +87,25 @@ class Scenario:
                 os.removedirs(dirpath)
 
     @property
-    def name(self):
+    def name(self):  # type: ignore[no-untyped-def]  # noqa: ANN201, D102
         return self.config.config["scenario"]["name"]
 
     @property
-    def directory(self):
+    def directory(self):  # type: ignore[no-untyped-def]  # noqa: ANN201, D102
         if self.config.molecule_file:
-            return os.path.dirname(self.config.molecule_file)
-        return os.getcwd()
+            return os.path.dirname(self.config.molecule_file)  # noqa: PTH120
+        return os.getcwd()  # noqa: PTH109
 
     @property
-    def ephemeral_directory(self):
+    def ephemeral_directory(self):  # type: ignore[no-untyped-def]  # noqa: ANN201, D102
         path = os.getenv("MOLECULE_EPHEMERAL_DIRECTORY", None)
         if not path:
-            project_directory = os.path.basename(self.config.project_directory)
+            project_directory = os.path.basename(self.config.project_directory)  # noqa: PTH119
 
             if self.config.is_parallel:
-                project_directory = f"{project_directory}-{self.config._run_uuid}"
+                project_directory = f"{project_directory}-{self.config._run_uuid}"  # noqa: SLF001
 
-            project_scenario_directory = os.path.join(
+            project_scenario_directory = os.path.join(  # noqa: PTH118
                 self.config.cache_directory,
                 project_directory,
                 self.name,
@@ -116,10 +114,10 @@ class Scenario:
             path = ephemeral_directory(project_scenario_directory)
 
         if os.environ.get("MOLECULE_PARALLEL", False) and not self._lock:
-            with open(os.path.join(path, ".lock"), "w") as self._lock:
+            with open(os.path.join(path, ".lock"), "w") as self._lock:  # type: ignore[assignment]  # noqa: PTH118, PTH123
                 for i in range(1, 5):
                     try:
-                        fcntl.lockf(self._lock, fcntl.LOCK_EX | fcntl.LOCK_NB)
+                        fcntl.lockf(self._lock, fcntl.LOCK_EX | fcntl.LOCK_NB)  # type: ignore[arg-type]
                         break
                     except OSError:
                         delay = 30 * i
@@ -136,79 +134,78 @@ class Scenario:
         return path
 
     @property
-    def inventory_directory(self):
-        return os.path.join(self.ephemeral_directory, "inventory")
+    def inventory_directory(self):  # type: ignore[no-untyped-def]  # noqa: ANN201, D102
+        return os.path.join(self.ephemeral_directory, "inventory")  # noqa: PTH118
 
     @property
-    def check_sequence(self):
+    def check_sequence(self):  # type: ignore[no-untyped-def]  # noqa: ANN201, D102
         return self.config.config["scenario"]["check_sequence"]
 
     @property
-    def cleanup_sequence(self):
+    def cleanup_sequence(self):  # type: ignore[no-untyped-def]  # noqa: ANN201, D102
         return self.config.config["scenario"]["cleanup_sequence"]
 
     @property
-    def converge_sequence(self):
+    def converge_sequence(self):  # type: ignore[no-untyped-def]  # noqa: ANN201, D102
         return self.config.config["scenario"]["converge_sequence"]
 
     @property
-    def create_sequence(self):
+    def create_sequence(self):  # type: ignore[no-untyped-def]  # noqa: ANN201, D102
         return self.config.config["scenario"]["create_sequence"]
 
     @property
-    def dependency_sequence(self):
+    def dependency_sequence(self):  # type: ignore[no-untyped-def]  # noqa: ANN201, D102
         return ["dependency"]
 
     @property
-    def destroy_sequence(self):
+    def destroy_sequence(self):  # type: ignore[no-untyped-def]  # noqa: ANN201, D102
         return self.config.config["scenario"]["destroy_sequence"]
 
     @property
-    def idempotence_sequence(self):
+    def idempotence_sequence(self):  # type: ignore[no-untyped-def]  # noqa: ANN201, D102
         return ["idempotence"]
 
     @property
-    def prepare_sequence(self):
+    def prepare_sequence(self):  # type: ignore[no-untyped-def]  # noqa: ANN201, D102
         return ["prepare"]
 
     @property
-    def side_effect_sequence(self):
+    def side_effect_sequence(self):  # type: ignore[no-untyped-def]  # noqa: ANN201, D102
         return ["side_effect"]
 
     @property
-    def syntax_sequence(self):
+    def syntax_sequence(self):  # type: ignore[no-untyped-def]  # noqa: ANN201, D102
         return ["syntax"]
 
     @property
-    def test_sequence(self):
+    def test_sequence(self):  # type: ignore[no-untyped-def]  # noqa: ANN201, D102
         return self.config.config["scenario"]["test_sequence"]
 
     @property
-    def verify_sequence(self):
+    def verify_sequence(self):  # type: ignore[no-untyped-def]  # noqa: ANN201, D102
         return ["verify"]
 
     @property
     def sequence(self) -> list[str]:
-        """Select the sequence based on scenario and subcommand of the provided scenario object and returns a list."""
+        """Select the sequence based on scenario and subcommand of the provided scenario object and returns a list."""  # noqa: E501
         result = []
-        our_scenarios = scenarios.Scenarios([self.config])  # type: ignore
-        matrix = our_scenarios._get_matrix()  # type: ignore
+        our_scenarios = scenarios.Scenarios([self.config])
+        matrix = our_scenarios._get_matrix()  # type: ignore[no-untyped-call]  # noqa: SLF001
 
         try:
             result = matrix[self.name][self.config.subcommand]
             if not isinstance(result, list):
-                raise RuntimeError("Unexpected sequence type {result}.")
+                raise RuntimeError(  # noqa: TRY003, TRY004
+                    "Unexpected sequence type {result}.",  # noqa: EM101
+                )
         except KeyError:
             pass
         return result
 
-    def _setup(self):
-        """Prepare the scenario for Molecule and returns None.
-
-        :return: None
-        """
-        if not os.path.isdir(self.inventory_directory):
-            os.makedirs(self.inventory_directory, exist_ok=True)
+    def _setup(self):  # type: ignore[no-untyped-def]  # noqa: ANN202
+        """Prepare the scenario for Molecule and returns None."""
+        if not os.path.isdir(self.inventory_directory):  # noqa: PTH112
+            os.makedirs(self.inventory_directory, exist_ok=True)  # noqa: PTH103
 
 
 def ephemeral_directory(path: str | None = None) -> str:
@@ -219,12 +216,12 @@ def ephemeral_directory(path: str | None = None) -> str:
     """
     d = os.getenv("MOLECULE_EPHEMERAL_DIRECTORY")
     if not d:
-        d = os.getenv("XDG_CACHE_HOME", os.path.expanduser("~/.cache"))
+        d = os.getenv("XDG_CACHE_HOME", os.path.expanduser("~/.cache"))  # noqa: PTH111
     if not d:
-        raise RuntimeError("Unable to determine ephemeral directory to use.")
-    d = os.path.abspath(os.path.join(d, path if path else "molecule"))
+        raise RuntimeError("Unable to determine ephemeral directory to use.")  # noqa: EM101, TRY003
+    d = os.path.abspath(os.path.join(d, path if path else "molecule"))  # noqa: PTH100, PTH118
 
-    if not os.path.isdir(d):
+    if not os.path.isdir(d):  # noqa: PTH112
         os.umask(0o077)
         Path(d).mkdir(mode=0o700, parents=True, exist_ok=True)
 
